from flask import *
import json, time
import pandas as pd
import numpy as np
from sklearn.model_selection import train_test_split
import pickle
from sklearn.ensemble import GradientBoostingRegressor
from sklearn.model_selection import cross_val_score
from flask_cors import CORS

data = pd.read_csv("Trains.csv")

def input_to_one_hot(data):
    
    enc_input = np.zeros(8)
    
    enc_input[0] = data['Wind_Speed']
    enc_input[1] = data['Average_Speed']
    enc_input[2] = data['Distance']
    enc_input[3] = data['Weater_Status_Drizzle']
    enc_input[4] = data['Weater_Status_Mostly_cloudy']
    enc_input[5] = data['Weater_Status_Rainy']
    enc_input[6] = data['Weater_Status_Sunny']
    enc_input[7] = data['Weater_Status_partialy_cloudy']
              
    return enc_input

num_cols = [col for col in data.columns if data[col].dtypes != 'O' and col not in "Id"]
print('Number of Numerical Variables: ', len(num_cols))
num_cols

X = data[['Weater_Status', 'Wind_Speed', 'Average_Speed', 'Distance']]

X.dropna(inplace=True)

Y = data.loc[:, data.columns != 'gps'].dropna().Delay_time
X = pd.get_dummies(data=X) 

X_train, X_test, Y_train, Y_test = train_test_split(X, Y, test_size = .20, random_state = 42)

from sklearn.ensemble import GradientBoostingRegressor
from sklearn.metrics import r2_score

gbr =GradientBoostingRegressor()
gbr.fit(X_train, Y_train)

predicted = gbr.predict(X_test)
residual = Y_test - predicted

from sklearn.metrics import mean_squared_error
rmse = np.sqrt(mean_squared_error(Y_test, predicted))
scores = cross_val_score(gbr, X, Y, cv=12)

# save model to file
pickle.dump(gbr, open("gbr2.pickle.dat", "wb"))

loaded_gbr = pickle.load(open("gbr2.pickle.dat", "rb"))

app = Flask(__name__)
CORS(app, resources={r"/delay/*": {"origins": "*"}})

@app.route('/delay/', methods=['GET'])
def request_page():
    
    user_input = {'Wind_Speed':float(request.args.get('wind')), 
              'Average_Speed':int(request.args.get('avg_speed')), 
              'Distance':float(request.args.get('distance')), 
              'Weater_Status_Drizzle':int(request.args.get('drizzle')),
              'Weater_Status_Mostly_cloudy':int(request.args.get('m_cloudy')),
              'Weater_Status_Rainy':int(request.args.get('rainy')),
              'Weater_Status_Sunny':int(request.args.get('sunny')),
              'Weater_Status_partialy_cloudy':int(request.args.get('p_cloudy')),
              }
    
    a = input_to_one_hot(user_input)

    delay_pred = loaded_gbr.predict([a])

    print(delay_pred[0])
    
    data = str(delay_pred[0])
    
    json_dump = json.dumps({"data":data})

    return json_dump

if __name__ == '__main__':
    app.run(host="127.0.0.1", port=7778,debug = True)
 
 #using this type
 #  http://127.0.0.1:7778/delay/?wind=15.65&avg_speed=55&distance=225.25&drizzle=0&m_cloudy=0&rainy=1&sunny=0&p_cloudy=0