import React from "react";
import { TextInput, View, Dimensions , ActivityIndicator , StyleSheet, TouchableOpacity, Text, Image, ScrollView , AsyncStorage } from "react-native";
import RadioForm from "react-native-simple-radio-button";
import AwesomeAlert from "react-native-awesome-alerts";
import axios from 'axios';
import LocalIP from './localIP';
import { DataTable } from 'react-native-paper';

const initialState = {
  page:0,
  npages: 0,
  page1:0,
  npages1: 0,
  localUri: "",
  Users:[],
  details:"",
  semail: "",
  message: "",
  showAlert: false,
  loader: false,
  title: "",
};

export default class AllUsers extends React.Component {

  constructor(props) {
    super(props);
  }
  
  state = initialState;

  static navigationOptions = ({ navigation}) => {
    return {
      headerTitle: 'All Users',
      headerStyle: { backgroundColor: '#9dffab' },
      headerTintColor: '#000000',
      headerLeft: () => {
        return null;
      }
    }
  };

  componentDidMount = async() => {
    const email = await AsyncStorage.getItem('email')
    const url = 'http://'+LocalIP+':3500/user/getCount';
    await axios.get(url,{
        headers: {'Content-Type': 'application/json'}
    })
    .then(async(res) => {
        var pages=Math.floor(res.data[0]['count']/5)
        if(res.data[0]['count']%5==0){
            
        }else{
            pages=parseInt(pages)+1
        }
        this.setState({npages:pages})

        const url = 'http://'+LocalIP+':3500/user/getQuarter';
        const data = JSON.stringify({ start: this.state.page*5 , length: 5 });
        await axios.post(url,data,{
            headers: {'Content-Type': 'application/json'}
        })
        .then(res => {
            this.setState({Users:res.data})
        })

    })
  }
  
  showAlert = () => {
    this.setState({
      showAlert: true,
    });
  };
  
  pageChange = async(page) => {
    this.setState({
      page: page,
    });
    
    const url = 'http://'+LocalIP+':3500/user/getQuarter';
    const data = JSON.stringify({ start: page*5 , length: 5 });
    await axios.post(url,data,{
        headers: {'Content-Type': 'application/json'}
    })
    .then(res => {
        this.setState({Users:res.data})
    })
  };

  pageChange1 = async(page) => {
    this.setState({
      page1: page,
    });
    
    const email = this.state.semail
    const url = 'http://'+LocalIP+':3500/my/getQuarter';
    const data = JSON.stringify({ email:email , start: page*5 , length: 5 });
    await axios.post(url,data,{
        headers: {'Content-Type': 'application/json'}
    })
    .then(res => {
        this.setState({Courses:res.data})
    })
  };

  hideAlert = () => {
    this.setState({
      showAlert: false,
      message: "",
      title: "",
    });
  };
  
  onSubmit = async(email,details) => {
    
    const url = 'http://'+LocalIP+':3500/my/getCount';
    const data = JSON.stringify({ email:email });
    await axios.post(url,data,{
        headers: {'Content-Type': 'application/json'}
    })
    .then(async(res) => {
        var pages=Math.floor(res.data[0]['count']/5)
        if(res.data[0]['count']%5==0){
            
        }else{
            pages=parseInt(pages)+1
        }

        if(pages==0){
          pages=1
        }

        if(parseInt(res.data[0]['count'])==0){
          this.setState({page1:0,npages1:1})
        }else{
          this.setState({npages1:pages})
        }

        const url = 'http://'+LocalIP+':3500/my/getQuarter';
        const data = JSON.stringify({ email:email , start: this.state.page*5 , length: 5 });
        await axios.post(url,data,{
            headers: {'Content-Type': 'application/json'}
        })
        .then(res => {
            this.setState({Courses:res.data,details:details,semail:email})
        })

    })

  };

  onSubmit1 = async(id) => {
    const url = 'http://'+LocalIP+':3500/my/'+id;
    await axios.delete(url,{
        headers: {'Content-Type': 'application/json'}
    })
    .then(res => {
        this.componentDidMount()
          if(res.data["err"]=="connection"){
            this.setState({ title: "Error!", message: "Connection Error!" });
            this.showAlert();
          }else{
            this.setState({title:"Success!",message:"Unenrolled!"})
            this.showAlert()
          }
    })
  };

  render() {
    const { showAlert , Users , Courses } = this.state;
    return (
      <ScrollView>
        <View style={styles.container}>
          <View style={styles.center}>
            <Image source={require("./../assets/logo.png")} style={{ width: 300, height: 300 }} />
          </View>

            <DataTable>
                <DataTable.Header>
                    <DataTable.Title>ID</DataTable.Title>
                    <DataTable.Title>First Name</DataTable.Title>
                    <DataTable.Title>Last Name</DataTable.Title>
                    <DataTable.Title>Email</DataTable.Title>
                    <DataTable.Title>Image</DataTable.Title>
                </DataTable.Header>
                {
                    Users.map((res) =>
                    <DataTable.Row>
                        <DataTable.Cell>{res.id}</DataTable.Cell>
                        <DataTable.Cell>{res.fname}</DataTable.Cell>
                        <DataTable.Cell>{res.lname}</DataTable.Cell>
                        <DataTable.Cell>{res.email}</DataTable.Cell>
                        <DataTable.Cell>
                          <Image source={{ uri: 'http://'+LocalIP+':3500/'+res.image }} style={{ width: 50, height: 50 }}  />
                        </DataTable.Cell>
                        <DataTable.Cell>
                        <TouchableOpacity style={[styles.listButton, styles.editButton]} onPress={ () => this.onSubmit(res.email,"ID : "+res.id+" Name : "+res.fname+" "+res.lname)} >
                            {!this.state.loader ? (
                                <Text style={{ color: "#000000", fontWeight: "bold" }}>View</Text>
                            ) : null}
                            {this.state.loader ? (
                                <ActivityIndicator size="large" color={"#ffffff"} />
                            ) : null}
                        </TouchableOpacity>
                        </DataTable.Cell>
                    </DataTable.Row>
                )}

                <DataTable.Pagination
                page={this.state.page}
                numberOfPages={this.state.npages}
                onPageChange={(page) => this.pageChange(page)}
                label={this.state.page+1+" of "+this.state.npages}
                />
            </DataTable>

            <View style={styles.center} >
              <Text style={{ color: "#000000", fontWeight: "bold" }}>{this.state.details}</Text>
            </View>
          <AwesomeAlert
            show={showAlert}
            title={this.state.title}
            message={this.state.message}
            closeOnTouchOutside={true}
            closeOnHardwareBackPress={false}
            showCancelButton={true}
            cancelText="Close"
            cancelButtonColor="#AEDEF4"
            onCancelPressed={() => {
              this.hideAlert();
            }}
          />
        </View>
      </ScrollView>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#ffffff',
    width: 100+'%'
  },
  center:{
    alignItems: 'center',
  },
  labelText:{
    fontWeight: 'bold' ,
    fontSize: 14 , 
    marginLeft: 10+'%',
    marginBottom: 10
  },
  firstLabelText:{
    fontWeight: 'bold' ,
    fontSize: 14 , 
    marginLeft: 10+'%',
    marginTop: 2+'%',
  },
  input: {
    borderBottomWidth: 1,
    width: 80 + '%',
    height:45,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  TextInputStyleClass:{
    borderBottomWidth: 1,
    width: 80 + '%',
    height:100,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  buttonContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 80 + '%',
    height: 40,
    borderRadius: 60
  },
  loginButton: {
    backgroundColor: "#9dffab",
  },
  registerButton: {
    backgroundColor: "#000000",
  },
  listButton: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 50, 
    marginTop:10,
    height: 40,
    borderRadius: 10
  },
  listButtonDelete: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 65, 
    marginTop:10,
    height: 40,
    borderRadius: 10
  },
  profilePic: {
    width: 350,
    height: 350,
  },
  profilePicView:{
    width: 350,
    height: 350,
    borderRadius: 350,
    borderBottomColor: '#000000',
    borderWidth: 2,
    overflow: 'hidden'
  },
  editButton: {
    backgroundColor: "#1cd92f",
  },
  deleteButton: {
    backgroundColor: "#ed0537",
  },
});
