import React from "react";
import { TextInput, View, ActivityIndicator , Picker , StyleSheet, TouchableOpacity, Text, Image, ScrollView , AsyncStorage} from "react-native";
import AwesomeAlert from "react-native-awesome-alerts";
import axios from 'axios';
import LocalIP from './localIP';

const initialState = {
  avg_speed: "",
  distance: "",
  wind: "",
  weather: "",
  hum: "",
  message: "",
  showAlert: false,
  loader: false,
  title: "",
  delay: "",
  pre: "",
};

export default class DelayP extends React.Component {

  state = initialState;

  static navigationOptions = ({ navigation}) => {
    return {
      headerTitle: 'Delay Prediction',
      headerStyle: { backgroundColor: '#9dffab' },
      headerTintColor: '#000000',
      headerLeft: () => {
        return null;
      }
    }
  };

  constructor(props) {
    super(props);
  }

  showAlert = () => {
    this.setState({
      showAlert: true,
    });
  };

  hideAlert = () => {
    this.setState({
      showAlert: false,
      message: "",
      title: "",
    });
  };

  validation =()=>{
    if (this.state.wind != "") {
      if (this.state.avg_speed != "") {
        if (this.state.distance != "") {
          if (this.state.weather != "") {
            return true;
          } else {
            this.setState({ title: "Required!", message: "Select weather!" });
            this.showAlert();
          }
        } else {
          this.setState({ title: "Required!", message: "Enter an Distance!" });
          this.showAlert();
        }
      } else {
        this.setState({ title: "Required!", message: "Enter an Average Speed!" });
        this.showAlert();
      }
    } else {
      this.setState({ title: "Required!", message: "Enter an wind!" });
      this.showAlert();
    }
    
    return false;
  }

  onSubmit = async(e) => {
    if(await this.validation()){
      var s=0,p=0,r=0,m=0,d=0
     if(this.state.weather==4){
        s=1
        p=0
        r=0
        m=0
        d=0
     }else if(this.state.weather==5){
      s=0
      p=1
      r=0
      m=0
      d=0
     }else if(this.state.weather==3){
      s=0
      p=0
      r=1
      m=0
      d=0
     }else if(this.state.weather==2){
      s=0
      p=0
      r=0
      m=1
      d=0
    }else if(this.state.weather==1){
      s=0
      p=0
      r=0
      m=0
      d=1
    }

     const urls1="http://"+LocalIP+":3500/prediction/delay"
     const data1 = JSON.stringify({ wind: this.state.wind , avg_speed: this.state.avg_speed , distance: this.state.distance , drizzle: d,m_cloudy: m,rainy: r,sunny: s,p_cloudy: p});
     await axios.post(urls1,data1,{
         headers: {'Content-Type': 'application/json'}
     }).then( res =>{
        this.setState({delay:res.data['data'],pre:"Predicted Delay"})
     })
    }
  };

  render() {
    const { showAlert } = this.state;
    return (
      <ScrollView>
        <View style={styles.container}>
          <View style={styles.center}>
            <Image
              source={require("./../assets/logo.png")}
              style={{ width: 350, height: 350 }}
            />
          </View>

          <View style={styles.center}>
            <Text style={{ color: "#000000", fontWeight: "bold", fontSize: 20 }}>{this.state.pre}</Text>
            <Text style={{ color: "#000000", fontWeight: "bold", fontSize: 15 }}>{this.state.delay}</Text>
          </View>

          <Text  style={styles.firstLabelText}>Wind Speed:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.wind}
              keyboardType = {'numeric'}
              onChangeText={(wind) => this.setState({wind })}
              placeholder={"Wind Speed"}
              style={styles.input}
            />
          </View>

          <Text  style={styles.firstLabelText}>Average Speed:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.avg_speed}
              keyboardType = {'numeric'}
              onChangeText={(avg_speed) => this.setState({avg_speed })}
              placeholder={"Average Speed"}
              style={styles.input}
            />
          </View>

          <Text  style={styles.firstLabelText}>Distance:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.distance}
              keyboardType = {'numeric'}
              onChangeText={(distance) => this.setState({distance })}
              placeholder={"Distance"}
              style={styles.input}
            />
          </View>

          <Text  style={styles.firstLabelText}>Weather:</Text>
          <View style={styles.center}>
          <View
            style={{
              borderBottomWidth: 1,
              width: 80 + '%',
              height:45,
              marginBottom:20,
              flexDirection: 'row',
              alignItems:'center',
              marginLeft: 4, 
              borderBottomColor: '#c4c4c4',
              color: '#000000',
            }}>
          <Picker
              selectedValue={this.state.weather}
              style={{width: 100 + '%',
              height:45}}
              onValueChange={(itemValue, itemIndex) => this.setState({weather: itemValue})}
            >
              <Picker.Item label="Select Weather" value="" />
              <Picker.Item label="Drizzle" value="1" />
              <Picker.Item label="Most Cloudy" value="2" />
              <Picker.Item label="Rainy" value="3" />
              <Picker.Item label="Sunny" value="4" />
              <Picker.Item label="Partialy Cloudy" value="5" />
            </Picker>
          </View>
          </View>

          <View style={styles.center}>
          <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={this.onSubmit} >
              {!this.state.loader ? (
                <Text style={{ color: "#000000", fontWeight: "bold" }}>Test</Text>
              ) : null}
              {this.state.loader ? (
                  <ActivityIndicator size="large" color={"#ffffff"} />
              ) : null}
          </TouchableOpacity>
          </View>

          <AwesomeAlert
            show={showAlert}
            title={this.state.title}
            message={this.state.message}
            closeOnTouchOutside={true}
            closeOnHardwareBackPress={false}
            showCancelButton={true}
            cancelText="Close"
            cancelButtonColor="#AEDEF4"
            onCancelPressed={() => {
              this.hideAlert();
            }}
          />
        </View>
      </ScrollView>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#ffffff',
  },
  center:{
    alignItems: 'center',
  },
  labelText:{
    fontWeight: 'bold' ,
    fontSize: 14 , 
    marginLeft: 10+'%',
    marginBottom: 10
  },
  firstLabelText:{
    fontWeight: 'bold' ,
    fontSize: 14 , 
    marginLeft: 10+'%',
    marginTop: 2+'%',
  },
  input: {
    borderBottomWidth: 1,
    width: 80 + '%',
    height:45,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  TextInputStyleClass:{
    borderBottomWidth: 1,
    width: 80 + '%',
    height:100,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  buttonContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 80 + '%',
    height: 40,
    borderRadius: 60
  },
  loginButton: {
    backgroundColor: "#9dffab",
  },
  registerButton: {
    backgroundColor: "#000000",
  }
});
