import React, { Component } from 'react';
import {  View, StyleSheet, TouchableOpacity, Text, Image , AsyncStorage } from 'react-native';
import 'react-native-gesture-handler';
import AwesomeAlert from 'react-native-awesome-alerts';

export default class Driver extends React.Component {
  constructor(props) {
    super(props);
    
    this.state = {
      message:'',
      showAlert: false,
      title:''
    };

    this.loadData()
  }

  loadData = async() =>{
    const isLoggedIn = await AsyncStorage.getItem('isLoggedIn')
    const userType = await AsyncStorage.getItem('userType')
    if(isLoggedIn=='true'&&userType=="Users"){
      this.props.navigation.navigate('Users')
    }else if(isLoggedIn=='true'&&userType=="Driver"){
      this.props.navigation.navigate('Driver')
    }
  }

  static navigationOptions = ({ navigation}) => {
    return {
      headerTitle: 'Driver Page',
      headerStyle: { backgroundColor: '#9dffab' },
      headerTintColor: '#000000',
    }
  };
  
  showAlert = () => {
    this.setState({
      showAlert: true
    });
  };
 
  hideAlert = () => {
    this.setState({
      showAlert: false,
      message: '',
      title: ''
    });
  };
  
  logout = async() => {
    AsyncStorage.clear();
    this.props.navigation.navigate('Login')
  }

  render() {
    const {showAlert} = this.state;
    return (
      <View style={styles.container}>
        <Image source={require('./../assets/logo.png')}
          style={{width: 200, height: 200 ,marginBottom:50 }} />

        <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={() =>  this.props.navigation.navigate('Profile')}>
          <Text style={{color: '#000000', fontWeight: 'bold'}}>Profile Update</Text>
        </TouchableOpacity>
        <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={() =>  this.props.navigation.navigate('Map')}>
          <Text style={{color: '#000000', fontWeight: 'bold'}}>Map</Text>
        </TouchableOpacity> 
        <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={() =>  this.props.navigation.navigate('Delay')}>
          <Text style={{color: '#000000', fontWeight: 'bold'}}>Delay & Weather</Text>
        </TouchableOpacity>
        <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={() =>  this.props.navigation.navigate('Weather')}>
          <Text style={{color: '#000000', fontWeight: 'bold'}}>Weather Prediction</Text>
        </TouchableOpacity>
        <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={() =>  this.props.navigation.navigate('DelayP')}>
          <Text style={{color: '#000000', fontWeight: 'bold'}}>Delay Prediction</Text>
        </TouchableOpacity>
        <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={() =>  this.props.navigation.navigate('Stations')}>
          <Text style={{color: '#000000', fontWeight: 'bold'}}>Arrived Stations</Text>
        </TouchableOpacity>
        <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={ this.logout }>
          <Text style={{color: '#000000', fontWeight: 'bold'}}>Logout</Text>
        </TouchableOpacity>

        <AwesomeAlert
            show={showAlert}
            title={this.state.title}
            message={this.state.message}
            closeOnTouchOutside={true}
            closeOnHardwareBackPress={false}
            showCancelButton={true}
            cancelText="Close"
            cancelButtonColor="#9dffab"
            onCancelPressed={() => {
              this.hideAlert();
            }}
          />

      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#ffffff',
  },
  input: {
    borderBottomWidth: 1,
    width: 80 + '%',
    height:45,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    marginLeft: 4, 
    borderBottomColor: '#9dffab',
    color: '#000000'
  },
  buttonContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 80 + '%',
    height: 40,
    borderRadius: 60
  },
  loginButton: {
    backgroundColor: "#9dffab",
  },
  registerButton: {
    backgroundColor: "#000000",
  }
});