import React, { Component } from 'react';
import { Alert, ActivityIndicator , TextInput, View, StyleSheet, TouchableOpacity, Text, Image , AsyncStorage } from 'react-native';
import 'react-native-gesture-handler';
import AwesomeAlert from 'react-native-awesome-alerts';
import axios from 'axios';
import LocalIP from './localIP';
import utf8 from 'utf8'
import base64 from 'base-64'

export default class Login extends React.Component {
  
  static navigationOptions = ({ navigation}) => {
    return {
      headerTitle: 'Login',
      headerStyle: { backgroundColor: '#9dffab' },
      headerTintColor: '#000000',
      headerLeft: () => {
        return null;
      }
    }
  };

  constructor(props) {
    super(props);
    
    this.state = {
      email: '',
      password: '',
      message:'',
      showAlert: false,
      loader: false,
      title:''
    }

    this.loadData()
  }

  loadData = async() =>{
    const isLoggedIn = await AsyncStorage.getItem('isLoggedIn')
    const userType = await AsyncStorage.getItem('userType')
    if(isLoggedIn=='true'&&userType=="Users"){
      this.props.navigation.navigate('Users')
    }else if(isLoggedIn=='true'&&userType=="Driver"){
      this.props.navigation.navigate('Driver')
    }
  }
  
  onLogin = async(e) => {
    
    this.setState({loader:true})

    const url = 'http://'+LocalIP+':3500/user/login/';
    const data = JSON.stringify({email: this.state.email , password: base64.encode(utf8.encode(this.state.password))});
    console.log(data)
    await axios.post(url,data,{
        headers: {'Content-Type': 'application/json'}
    })
    .then(async(res)=>{
      this.setState({loader:false})
      if(res.data["err"]=="user_email"){
        console.log("email")
        this.setState({ title: "Error!", message: "This Email not has our database!" ,email:"" ,password:"" });
        this.showAlert();
      }else if(res.data["err"]=="connection"){
        console.log("connection")
        this.setState({ title: "Error!", message: "Connection Error!" });
        this.showAlert();
      }else if(res.data["err"]=="user_password"){
        console.log("password")
        this.setState({ title: "Error!", message: "Invalid Password!" });
        this.showAlert();
      }else{
        if(res.data){
          console.log(res.data)
          if(res.data['userType']==1){
            await AsyncStorage.setItem('isLoggedIn','true')
            await AsyncStorage.setItem('userType',"Users")
            await AsyncStorage.setItem('email',res.data['email'])
            this.props.navigation.navigate('Users')
          }else if(res.data['userType']==2 && res.data['access']==1){
            await AsyncStorage.setItem('isLoggedIn','true')
            await AsyncStorage.setItem('userType',"Driver")
            await AsyncStorage.setItem('email',res.data['email'])
            this.props.navigation.navigate('Driver')
          }else if(res.data['userType']==3 && res.data['access']==1){
            await AsyncStorage.setItem('isLoggedIn','true')
            await AsyncStorage.setItem('userType',"Admin")
            await AsyncStorage.setItem('email',res.data['email'])
            this.props.navigation.navigate('Users')
          }else {
            this.setState({ title: "Error!", message: "no permission!" });
            this.showAlert();
          }
          
        }
      }
    })

  }
  
  showAlert = () => {
    this.setState({
      showAlert: true
    });
  };
 
  hideAlert = () => {
    this.setState({
      showAlert: false,
      message: '',
      title: ''
    });
  };

  render() {
    const {showAlert} = this.state;
    return (
      <View style={styles.container}>
        <Image source={require('./../assets/logo.png')}
          style={{width: 350, height: 350}} />
        
        <TextInput 
          value={this.state.email}
          onChangeText={(email) => this.setState({ email })}
          placeholder={'Email'}
          style={styles.input}
        />
        <TextInput
          value={this.state.password}
          onChangeText={(password) => this.setState({ password })}
          placeholder={'Password'}
          secureTextEntry={true}
          style={styles.input}
        />
        
        <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={ this.onLogin }>
          {!this.state.loader ? (
            <Text style={{color: '#000000', fontWeight: 'bold'}}>Login</Text>
          ) : null}
          {this.state.loader ? (
              <ActivityIndicator size="large" color={"#000000"} />
          ) : null}
        </TouchableOpacity>

        <TouchableOpacity onPress={() =>  this.props.navigation.navigate('Register')} style={[styles.buttonContainer, styles.registerButton]}> 
          <Text style={{color: '#ffffff', fontWeight: 'bold'}}>Register</Text>
        </TouchableOpacity>

        <TouchableOpacity style={styles.buttonContainer} onPress={() => this.props.navigation.navigate('ForgotPassword')}>
            <Text>Forgot your password?</Text>
        </TouchableOpacity>

        <AwesomeAlert
            show={showAlert}
            title={this.state.title}
            message={this.state.message}
            closeOnTouchOutside={true}
            closeOnHardwareBackPress={false}
            showCancelButton={true}
            cancelText="Close"
            cancelButtonColor="#AEDEF4"
            onCancelPressed={() => {
              this.hideAlert();
            }}
          />

      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#ffffff',
  },
  input: {
    borderBottomWidth: 1,
    width: 80 + '%',
    height:45,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    marginLeft: 4, 
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  buttonContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 80 + '%',
    height: 40,
    borderRadius: 60
  },
  loginButton: {
    backgroundColor: "#9dffab",
  },
  registerButton: {
    backgroundColor: "#000000",
  }
});