import React, { Component } from 'react';
import { Alert, Button, Picker , ActivityIndicator , TextInput , View, StyleSheet, TouchableOpacity, Text, Image , AsyncStorage , Dimensions , ScrollView } from 'react-native';
import 'react-native-gesture-handler';
import AwesomeAlert from 'react-native-awesome-alerts';
import MapView from 'react-native-maps';
import Constants from 'expo-constants';
import * as Location from 'expo-location';

export default class Map extends React.Component {
  constructor(props) {
    super(props);
    
    this.state = {
      message:'',
      showAlert: false,
      loader: false,
      title:'',
      latitude: '',
      longitude: ''
    };

    this.loadData()
    this.getLocationHandler()
  }

  loadData = async() =>{
    const isLoggedIn = await AsyncStorage.getItem('isLoggedIn')
    const userType = await AsyncStorage.getItem('userType')
    if(isLoggedIn=='true'&&userType=="Users"){
      this.props.navigation.navigate('Users')
    }else if(isLoggedIn=='true'&&userType=="Driver"){
      this.props.navigation.navigate('Driver')
    }
  }

  static navigationOptions = ({ navigation}) => {
    return {
      headerTitle: 'Map',
      headerStyle: { backgroundColor: '#9dffab' },
      headerTintColor: '#000000',
    }
  };

  componentDidMount() {

    if (Platform.OS === 'android' && !Constants.isDevice) {
      alert(
        'Oops, this will not work on Sketch in an Android emulator. Try it on your device!'
      );
    } else {
      (async () => {
        let { status } = await Location.requestPermissionsAsync();
        if (status !== 'granted') {
          alert('Permission to access location was denied');
        }

        var location = await Location.installWebGeolocationPolyfill()
      })();
    }
   }

  logout = async() => {
    AsyncStorage.clear();
    this.props.navigation.navigate('Login')
  }

  loadData = async() =>{
    const isLoggedIn = await AsyncStorage.getItem('isLoggedIn')
    if(isLoggedIn!=='true'){

    }
  }
  
  showAlert = () => {
    this.setState({
      showAlert: true
    });
  };
 
  hideAlert = () => {
    this.setState({
      showAlert: false,
      message: '',
      title: ''
    });
  };

  getLocationHandler = () => {
    navigator.geolocation.getCurrentPosition(pos => {
      this.setState({latitude:pos.coords.latitude,longitude:pos.coords.longitude})
    },
    err => {
      console.log(err);
      alert("Fetching the Position failed, please pick one manually!");
    })
    console.log(this.state.latitude+" "+this.state.longitude)
  }

  render() {
    const {showAlert} = this.state;
    const {diseaseArray} = this.state;
    let marker = null;

    if (this.state.locationChosen) {
      marker = <MapView.Marker coordinate={this.state.focusedLocation} />;
    }
    return (
      <ScrollView style={styles.scrollView}>
        <View style={styles.container}>
          <Image source={require('./../assets/logo.png')}
            style={{width: 120, height: 120 ,marginBottom:20 , marginTop:10}} />

            <MapView
            initialRegion={this.state.focusedLocation}
            region={!this.state.locationChosen ? this.state.focusedLocation : null}
            style={{width: 80 + '%', 
              height: Dimensions.get('window').height*0.8 ,
              borderWidth: 1,
              marginBottom:10 , 
              marginLeft: 4,
              borderColor: '#c4c4c4',
              }}
            onLongPress={this.pickLocationHandler}
            zoomEnabled={true}
            pitchEnabled={true}
            showsUserLocation={true}
            followsUserLocation={true}
            showsCompass={true}
            showsBuildings={true}
            showsIndoors={true}
            ref={ref => this.map = ref}
          >
            {marker}
          </MapView>

          <AwesomeAlert
              show={showAlert}
              title={this.state.title}
              message={this.state.message}
              closeOnTouchOutside={true}
              closeOnHardwareBackPress={false}
              showCancelButton={true}
              cancelText="Close"
              cancelButtonColor="#AEDEF4"
              onCancelPressed={() => {
                this.hideAlert();
              }}
            />

        </View>
      </ScrollView>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#ffffff',
  },
  map: {
    width: "100%",
    height: 600
  },
  button: {
    margin: 8
  },
  input: {
    borderBottomWidth: 1,
    width: 80 + '%',
    height:45,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    marginLeft: 4, 
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  TextInputStyleClass:{
    borderBottomWidth: 1,
    width: 80 + '%',
    height:100,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    marginLeft: 4, 
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  buttonContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 80 + '%',
    height: 40,
    borderRadius: 60
  },
  loginButton: {
    backgroundColor: "#348ceb",
  },
  registerButton: {
    backgroundColor: "#7b00ff",
  }
});