import React from "react";
import { TextInput, View, Dimensions , ActivityIndicator , StyleSheet, TouchableOpacity, Text, Image, ScrollView , AsyncStorage } from "react-native";
import RadioForm from "react-native-simple-radio-button";
import AwesomeAlert from "react-native-awesome-alerts";
import axios from 'axios';
import LocalIP from './localIP';
import utf8 from 'utf8'
import base64 from 'base-64'
import * as ImagePicker from 'expo-image-picker';

const initialState = {
  id:"",
  fname: "",
  lname: "",
  email: "",
  password: "",
  cpassword: "",
  type: "0",
  localUri: "",
  path:"",
  message: "",
  showAlert: false,
  loader: false,
  title: "",
};

var radio_props = [
  { label: "Passenger  ", value: "1" },
  { label: "Driver", value: "2" },
];

export default class Profile extends React.Component {

  constructor(props) {
    super(props);
  }
  
  state = initialState;

  static navigationOptions = ({ navigation}) => {
    return {
      headerTitle: 'User Profile',
      headerStyle: { backgroundColor: '#9dffab' },
      headerTintColor: '#000000',
      headerLeft: () => {
        return null;
      }
    }
  };

  componentDidMount = async() => {
    const email = await AsyncStorage.getItem('email')
    const url = 'http://'+LocalIP+':3500/user/'+email;
    await axios.get(url,{
        headers: {'Content-Type': 'application/json'}
    })
    .then(res => {
      this.setState({ id: res.data[0]['id'] ,fname: res.data[0]['fname'] , lname: res.data[0]['lname'] , email: res.data[0]['email'] , type: res.data[0]['userType'] ,path: res.data[0]['image'] });
    })
  }
  
  openImagePickerAsync = async (e) => {
    let permissionResult = await ImagePicker.requestCameraRollPermissionsAsync();

    if (permissionResult.granted === false) {
      this.setState({title:"Permission Denied!",message:"Permission to access camera roll is required!"})
      this.showAlert()
      return;
    }

    let pickerResult = await ImagePicker.launchImageLibraryAsync();
    
    if (pickerResult.cancelled === true) {
      return;
    }

    await this.setState({ localUri: pickerResult.uri });
  }

  showAlert = () => {
    this.setState({
      showAlert: true,
    });
  };

  hideAlert = () => {
    this.setState({
      showAlert: false,
      message: "",
      title: "",
    });
  };

  postImage = async (uri) => {
    const url = 'http://'+LocalIP+':3500/user/upload';
    const photo = {
      uri: uri,
      type: "image/jpg",
      name: "photo.jpg",
    };

    const form = new FormData();

    form.append("file", photo);

    await axios.post(url,form
    ).then(async(responseData) => {
      await this.setState({'path':responseData.data['filename']})
      console.log(responseData.data['filename'])
    })
    .catch((error) => {
      console.log("ERROR " + error)
    });
  }

  validation =async(path)=>{
    if (this.state.email != "") {
      if (this.state.fname != "") {
        if (this.state.lname != "") {
          if (this.state.password != "") {
            if (this.state.cpassword != "") {
              if (this.state.password == this.state.cpassword) {
                var reg = /^\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,3})+$/;
                if (reg.test(this.state.email) === true){
                  console.log(path)
                  if(path){
                    await this.postImage(path)
                    return true;
                  }else{
                    return true;
                  }
                } else {
                  this.setState({
                    title: "Error!",
                    message: "Invalid Email!",
                  });
                  this.showAlert();
                }

              } else {
                this.setState({
                  title: "Error!",
                  message: "Password & Confirm Password Not Equals!",
                });
                this.showAlert();
              }
            } else {
              this.setState({
                title: "Required!",
                message: "Enter an Confirm Password!",
              });
              this.showAlert();
            }
          } else {
            this.setState({ title: "Required!", message: "Enter an Password!" });
            this.showAlert();
          }
        } else {
          this.setState({ title: "Required!", message: "Enter an Last Name!" });
          this.showAlert();
        }
      } else {
        this.setState({ title: "Required!", message: "Enter an First Name!" });
        this.showAlert();
      }
    } else {
      this.setState({ title: "Required!", message: "Enter an Email!" });
      this.showAlert();
    }
    return false;
  }

  onSubmit = async(e) => {
    if(await this.validation(this.state.localUri)){
      this.setState({loader:true})
      const url = 'http://'+LocalIP+':3500/user/'+this.state.id;
      console.log(this.state.path)
      const data = JSON.stringify({ fname: this.state.fname , lname: this.state.lname , email: this.state.email , password: base64.encode(utf8.encode(this.state.password)) , userType: this.state.type , image:this.state.path });
      await axios.put(url,data,{
          headers: {'Content-Type': 'application/json'}
      })
      .then(res => {
          console.log(res.data["err"]);
          this.setState(initialState)
          this.componentDidMount()
          if(res.data["err"]=="email"){
            this.setState({ title: "Error!", message: "This Email Already Exists!" ,email:"" });
            this.showAlert();
          }else if(res.data["err"]=="connection"){
            this.setState({ title: "Error!", message: "Connection Error!" });
            this.showAlert();
          }else if(res.data["err"]=="data"){
            this.setState({ title: "Error!", message: "Invalid Data!" });
            this.showAlert();
          }else{
            this.setState({title:"Success!",message:"Update Successful!"})
            this.showAlert()
          }
      })
    }
  };

  render() {
    const { showAlert } = this.state;
    return (
      <ScrollView>
        <View style={styles.container}>
          <View style={styles.center}>
            {this.state.path ? (
              <View style={styles.profilePicView}>
                <Image source={{ uri: 'http://'+LocalIP+':3500/'+this.state.path }} style={styles.profilePic} />
              </View>
            ) : null}
            {!this.state.path ? (
            <Image source={require("./../assets/logo.png")} style={{ width: 350, height: 350 }}
            />
            ) : null}
          </View>

          <Text  style={styles.firstLabelText}>First Name:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.fname}
              onChangeText={(fname) => this.setState({ fname })}
              placeholder={"First Name"}
              style={styles.input}
            />
          </View>

          <Text  style={styles.firstLabelText}>Last Name:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.lname}
              onChangeText={(lname) => this.setState({ lname })}
              placeholder={"Last Name"}
              style={styles.input}
            />
          </View>

          <Text  style={styles.firstLabelText}>Email:</Text>
          <View style={styles.center}>
          <TextInput
            value={this.state.email}
            onChangeText={(email) => this.setState({ email })}
            placeholder={"Email"}
            style={styles.input}
          />
          </View>

          <Text  style={styles.firstLabelText}>Password:</Text>
          <View style={styles.center}>
          <TextInput
            value={this.state.password}
            onChangeText={(password) => this.setState({ password })}
            placeholder={"Password"}
            secureTextEntry={true}
            style={styles.input}
          />
          </View>

          <Text  style={styles.firstLabelText}>Confirm Password:</Text>
          <View style={styles.center}>
          <TextInput
            value={this.state.cpassword}
            onChangeText={(cpassword) => this.setState({ cpassword })}
            placeholder={"Confirm Password"}
            secureTextEntry={true}
            style={styles.input}
          />
          </View>

          <Text  style={styles.firstLabelText}>User Type:{"\n"}</Text>
          <View style={styles.center}>
            <RadioForm
              radio_props={radio_props}
              formHorizontal={true}
              labelHorizontal={true}
              buttonColor={"#000000"}
              selectedButtonColor={"#9dffab"}
              animation={true}
              buttonSize={15}
              labelStyle={{ fontSize: 15 }}
              style={{ marginBottom: 30 }}
              initial={ this.state.type*1-1 }
              onPress={(value) => {
                this.setState({ type: value });
              }}
              value={this.state.type}
            />
          </View>

          <Text  style={styles.labelText}>Image:</Text>
          <View style={styles.center}>
            <TouchableOpacity onPress={this.openImagePickerAsync} style={{width: 80 + '%', 
              height: Dimensions.get('window').width*0.8 ,
              borderWidth: 1,
              marginBottom:10 , 
              marginTop: 10,
              borderColor: '#c4c4c4',
              }}>
                <View>
                  <Image source={{ uri: this.state.localUri }}
                    style={{width: 100 + '%', 
                    height: 100 + '%' 
                    }}
                    />
                </View>
            </TouchableOpacity>
            <TouchableOpacity style={[styles.buttonContainer, styles.registerButton , {width: 50 + '%'}]} onPress={this.openImagePickerAsync}>
              <Text style={{color: '#ffffff', fontWeight: 'bold'}}>Choose Image</Text>
            </TouchableOpacity>
          </View>

          <View style={styles.center}>
          <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={this.onSubmit} >
              {!this.state.loader ? (
                <Text style={{ color: "#000000", fontWeight: "bold" }}>Update</Text>
              ) : null}
              {this.state.loader ? (
                  <ActivityIndicator size="large" color={"#ffffff"} />
              ) : null}
          </TouchableOpacity>

          </View>

          <AwesomeAlert
            show={showAlert}
            title={this.state.title}
            message={this.state.message}
            closeOnTouchOutside={true}
            closeOnHardwareBackPress={false}
            showCancelButton={true}
            cancelText="Close"
            cancelButtonColor="#AEDEF4"
            onCancelPressed={() => {
              this.hideAlert();
            }}
          />
        </View>
      </ScrollView>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#ffffff',
  },
  center:{
    alignItems: 'center',
  },
  labelText:{
    fontWeight: 'bold' ,
    fontSize: 14 , 
    marginLeft: 10+'%',
    marginBottom: 10
  },
  firstLabelText:{
    fontWeight: 'bold' ,
    fontSize: 14 , 
    marginLeft: 10+'%',
    marginTop: 2+'%',
  },
  input: {
    borderBottomWidth: 1,
    width: 80 + '%',
    height:45,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  TextInputStyleClass:{
    borderBottomWidth: 1,
    width: 80 + '%',
    height:100,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  buttonContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 80 + '%',
    height: 40,
    borderRadius: 60
  },
  loginButton: {
    backgroundColor: "#9dffab",
  },
  registerButton: {
    backgroundColor: "#000000",
  },
  profilePic: {
    width: 350,
    height: 350,
  },
  profilePicView:{
    width: 350,
    height: 350,
    borderRadius: 350,
    borderBottomColor: '#000000',
    borderWidth: 2,
    overflow: 'hidden'
  },
});
