import React, { Component } from 'react';
import { Alert, Button, Picker , ActivityIndicator , TextInput , View, StyleSheet, TouchableOpacity, Text, Image , AsyncStorage , Dimensions  , ScrollView } from 'react-native';
import 'react-native-gesture-handler';
import AwesomeAlert from 'react-native-awesome-alerts';
import axios from 'axios';
import LocalIP from './localIP';

export default class UserStations extends React.Component {
  constructor(props) {
    super(props);
    
    this.state = {
      message:'',
      showAlert: false,
      loader: false,
      title:'',
      latitude:'',
      longitude:'',
      stations:[]
    };

    this.interval = setInterval(() => {
      this.componentDidMount();
    }, 5000);

  }

  loadData = async() =>{
    const isLoggedIn = await AsyncStorage.getItem('isLoggedIn')
    const userType = await AsyncStorage.getItem('userType')
    if(isLoggedIn=='true'&&userType=="Users"){
      this.props.navigation.navigate('Users')
    }else if(isLoggedIn=='true'&&userType=="Driver"){
      this.props.navigation.navigate('Driver')
    }
  }

  static navigationOptions = ({ navigation}) => {
    return {
      headerTitle: 'Arrived Stations',
      headerStyle: { backgroundColor: '#9dffab' },
      headerTintColor: '#000000',
    }
  };

  componentDidMount= async() =>{
    const url="http://"+LocalIP+":3500/prediction/stations"
    await axios.get(url,{
         headers: {'Content-Type': 'application/json'}
     }).then( async(res) =>{

      console.log(res)

      const tempArray = [];

      for (var i=0; i < res.data.length; i++) {
        var dis=0

        if(res.data[i].f1<res.data[i].f2){
          dis=3;
        }else if(res.data[i].f1>res.data[i].f2){
          dis=2;
        }

        if(res.data[i].f2.toFixed(1)*1==0.0){
          dis=1;
        }

        tempArray.push({ name: res.data[i].name, dis: dis });

      }
      console.log(tempArray)

      this.setState({stations:tempArray})

    })
  }

  logout = async() => {
    AsyncStorage.clear();
    this.props.navigation.navigate('Login')
  }

  loadData = async() =>{
    const isLoggedIn = await AsyncStorage.getItem('isLoggedIn')
    if(isLoggedIn!=='true'){

    }
  }
  
  showAlert = () => {
    this.setState({
      showAlert: true
    });
  };
 
  hideAlert = () => {
    this.setState({
      showAlert: false,
      message: '',
      title: ''
    });
  };

  render() {
    const {showAlert} = this.state;
    const {stations} = this.state;

    return (
      <ScrollView style={styles.scrollView}>
        <View style={styles.container}>
          <Image source={require('./../assets/logo.png')}
            style={{width: 120, height: 120 ,marginBottom:20 , marginTop:10}} />
          {
            stations.map((record) =>
            <View style={{width: 80 + '%',flex: 1, flexDirection: 'row',marginBottom:5}}>
              <View style={{width: 50 + '%',marginBottom:5,alignItems: 'center',justifyContent: 'center'}}>
                <Text style={{color: '#000000', fontWeight: 'bold' ,fontSize: 20}}>{record.name}</Text>
              </View>
              {record.dis == 3 ? (
                <View style={{width: 50 + '%',marginBottom:5,alignItems: 'center',justifyContent: 'center'}}>
                  <Image source={require('./../assets/right.png')} style={{width: 40, height: 40 ,marginBottom:20 , marginTop:10}} />
                </View>
              ):null}

              {record.dis == 2 ? (
                <View style={{width: 50 + '%',marginBottom:5,alignItems: 'center',justifyContent: 'center'}}>
                  <Image source={require('./../assets/loading.png')} style={{width: 40, height: 40 ,marginBottom:20 , marginTop:10}} />
                </View>
              ):null}

              {record.dis == 0 ? (
                <View style={{width: 50 + '%',marginBottom:5,alignItems: 'center',justifyContent: 'center'}}>
                  <Image source={require('./../assets/wait.png')} style={{width: 40, height: 40 ,marginBottom:20 , marginTop:10}} />
                </View>
              ):null}

              {record.dis == 1 ? (
                <View style={{width: 50 + '%',marginBottom:5,alignItems: 'center',justifyContent: 'center'}}>
                  <Image source={require('./../assets/location-icon.png')} style={{width: 40, height: 40 ,marginBottom:20 , marginTop:10}} />
                </View>
              ):null}
              
            </View>
          )}

          <AwesomeAlert
              show={showAlert}
              title={this.state.title}
              message={this.state.message}
              closeOnTouchOutside={true}
              closeOnHardwareBackPress={false}
              showCancelButton={true}
              cancelText="Close"
              cancelButtonColor="#AEDEF4"
              onCancelPressed={() => {
                this.hideAlert();
              }}
            />

        </View>
      </ScrollView>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#ffffff',
  },
  map: {
    width: "100%",
    height: 600
  },
  button: {
    margin: 8
  },
  input: {
    borderBottomWidth: 1,
    width: 80 + '%',
    height:45,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    marginLeft: 4, 
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  TextInputStyleClass:{
    borderBottomWidth: 1,
    width: 80 + '%',
    height:100,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    marginLeft: 4, 
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  buttonContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 80 + '%',
    height: 40,
    borderRadius: 60
  },
  loginButton: {
    backgroundColor: "#348ceb",
  },
  registerButton: {
    backgroundColor: "#7b00ff",
  }
});