import React from "react";
import { TextInput, View, ActivityIndicator , Picker , StyleSheet, TouchableOpacity, Text, Image, ScrollView , AsyncStorage} from "react-native";
import AwesomeAlert from "react-native-awesome-alerts";
import axios from 'axios';
import LocalIP from './localIP';

const initialState = {
  time: "",
  lat: "",
  lang: "",
  temp: "",
  hum: "",
  message: "",
  weather:"",
  showAlert: false,
  loader: false,
  title: "",
  pre:""
};

export default class Weather extends React.Component {

  state = initialState;

  static navigationOptions = ({ navigation}) => {
    return {
      headerTitle: 'Weather Prediction',
      headerStyle: { backgroundColor: '#9dffab' },
      headerTintColor: '#000000',
      headerLeft: () => {
        return null;
      }
    }
  };

  constructor(props) {
    super(props);
  }

  showAlert = () => {
    this.setState({
      showAlert: true,
    });
  };

  hideAlert = () => {
    this.setState({
      showAlert: false,
      message: "",
      title: "",
    });
  };

  validation =()=>{
    if (this.state.time != "") {
      if (this.state.lat != "") {
        if (this.state.lang != "") {
          if (this.state.temp != "") {
            if (this.state.hum != "") {
              return true;
            } else {
              this.setState({ title: "Required!", message: "Enter an Humidity!" });
              this.showAlert();
            }
          } else {
            this.setState({ title: "Required!", message: "Enter an Temperature!" });
            this.showAlert();
          }
        } else {
          this.setState({ title: "Required!", message: "Enter an Longitude!" });
          this.showAlert();
        }
      } else {
        this.setState({ title: "Required!", message: "Enter an Latitude!" });
        this.showAlert();
      }
    } else {
      this.setState({ title: "Required!", message: "Enter an time !" });
      this.showAlert();
    }
    
    return false;
  }

  onSubmit = async(e) => {
    if(await this.validation()){
     const urls="http://"+LocalIP+":3500/prediction/weather"
     const data = JSON.stringify({ time: this.state.time , lat: this.state.lat , lang: this.state.lang , temp: this.state.temp , hum: this.state.hum });
     await axios.post(urls,data,{
         headers: {'Content-Type': 'application/json'}
     }).then( res =>{
        this.setState({weather:res.data['data'],pre:"Predicted Weather"})
     })
    }
  };

  render() {
    const { showAlert } = this.state;
    return (
      <ScrollView>
        <View style={styles.container}>
          <View style={styles.center}>
            <Image
              source={require("./../assets/logo.png")}
              style={{ width: 350, height: 350 }}
            />
          </View>

          <View style={styles.center}>
            <Text style={{ color: "#000000", fontWeight: "bold", fontSize: 20 }}>{this.state.pre}</Text>
            <Text style={{ color: "#000000", fontWeight: "bold", fontSize: 15 }}>{this.state.weather}</Text>
          </View>

          <Text  style={styles.firstLabelText}>Time:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.time}
              keyboardType = {'numeric'}
              onChangeText={(time) => this.setState({time })}
              placeholder={"Time"}
              style={styles.input}
            />
          </View>

          <Text  style={styles.firstLabelText}>Latitude:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.lat}
              keyboardType = {'numeric'}
              onChangeText={(lat) => this.setState({lat })}
              placeholder={"Latitude"}
              style={styles.input}
            />
          </View>

          <Text  style={styles.firstLabelText}>Longitude:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.lang}
              keyboardType = {'numeric'}
              onChangeText={(lang) => this.setState({lang })}
              placeholder={"Longitude"}
              style={styles.input}
            />
          </View>

          <Text  style={styles.firstLabelText}>Temperature:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.temp}
              onChangeText={(temp) => this.setState({temp })}
              placeholder={"Temperature"}
              keyboardType = {'numeric'}
              style={styles.input}
            />
          </View>

          <Text  style={styles.firstLabelText}>Humidity:</Text>
          <View style={styles.center}>
            <TextInput
              value={this.state.hum}
              onChangeText={(hum) => this.setState({hum })}
              placeholder={"Humidity"}
              keyboardType = {'numeric'}
              style={styles.input}
            />
          </View>

          <View style={styles.center}>
          <TouchableOpacity style={[styles.buttonContainer, styles.loginButton]} onPress={this.onSubmit} >
              {!this.state.loader ? (
                <Text style={{ color: "#000000", fontWeight: "bold" }}>Test</Text>
              ) : null}
              {this.state.loader ? (
                  <ActivityIndicator size="large" color={"#ffffff"} />
              ) : null}
          </TouchableOpacity>

          </View>

          <AwesomeAlert
            show={showAlert}
            title={this.state.title}
            message={this.state.message}
            closeOnTouchOutside={true}
            closeOnHardwareBackPress={false}
            showCancelButton={true}
            cancelText="Close"
            cancelButtonColor="#AEDEF4"
            onCancelPressed={() => {
              this.hideAlert();
            }}
          />
        </View>
      </ScrollView>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#ffffff',
  },
  center:{
    alignItems: 'center',
  },
  labelText:{
    fontWeight: 'bold' ,
    fontSize: 14 , 
    marginLeft: 10+'%',
    marginBottom: 10
  },
  firstLabelText:{
    fontWeight: 'bold' ,
    fontSize: 14 , 
    marginLeft: 10+'%',
    marginTop: 2+'%',
  },
  input: {
    borderBottomWidth: 1,
    width: 80 + '%',
    height:45,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  TextInputStyleClass:{
    borderBottomWidth: 1,
    width: 80 + '%',
    height:100,
    marginBottom:20,
    flexDirection: 'row',
    alignItems:'center',
    borderBottomColor: '#c4c4c4',
    color: '#000000'
  },
  buttonContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom:10,
    width: 80 + '%',
    height: 40,
    borderRadius: 60
  },
  loginButton: {
    backgroundColor: "#9dffab",
  },
  registerButton: {
    backgroundColor: "#000000",
  }
});
